# habitat - Next Generation High Altitude Balloon Tracking System

habitat is a web application for tracking the flight path of high altitude
balloons, relying on a network of users with radios sending in received
telemetry strings which are parsed into position information and displayed
on maps.

Written by various UKHAS members, see AUTHORS.

## Dependencies

```bash
    $ pip install -r requirements.txt

    # for testing
    $ pip install nose mox
```

## Installation

habitat isn't really ready to be installed just yet. Watch this space!

## Project Homepage

 - [habitat documentation on habhub](http://habitat.habhub.org/) - rendered
   documents generated by sphinx; the source code is in the docs folder
 - [habitat on github](http://github.com/ukhas/habitat)

## License

habitat is licensed under the GNU GPLv3, see LICENSE.
